## worker

### Installation

1. Clone the repo
   ```sh
   git clone https://github.com/(user_name)/worker.git
   ```
   
2. Create venv
   ```sh
   python3 -m venv venv
   ```
   
3. Activate venv
   ```sh
   . venv/bin/activate
   ```
 
4. Install requirements.txt
   ```sh
   pip install -r requirements.txt
   ```
5. To start application
   ```sh
   sh run.sh
   ```
6. Worksite Vision Website
   ```sh
   worksitevision.com
   ```
   
7. Fix some issue
Fix python: export PYTHONPATH="/venv/bin/python3.9" 
new

